@@ -56,7 +56,8 @@ class HTTPClient(object):
         if 'cube' in kwargs and kwargs['cube']:
             try:
                 cube_cls = get_cube(kwargs['cube'])
-            except ImportError:
+            except ImportError as e:
+                print e
                 cube_cls = cls
         else:
             cube_cls = cls
